<?php

namespace Drupal\syncloud\Service;

use Drupal\user\Entity\User;

/**
 * Class Connector.
 */
class Queue
{
  /**
   * Init funciton.
   */
  public function __construct() {
    $this->storage = \Drupal::entityTypeManager()->getStorage('contact_message');
    $this->syn_storage = \Drupal::entityTypeManager()->getStorage('syn');
  }
  /**
   * Push entity to queue.
   */
  public function queuePush(int $id) {
    $queue = \Drupal::queue('syncloud_queue');
    $queue->createQueue();
    $queue->createItem([
      'id' => $id,
    ]);
  }

  /**
   * Process queue.
   */
  public function queueProcess() {
    $end = time() + 30;
    $queue = \Drupal::queue('syncloud_queue');
    while (time() < $end && ($item = $queue->claimItem())) {
      $entity = $this->storage->load($item->data['id']);
      $form_id = $entity->getContactForm()->id();
      $ip = \Drupal::request()->getClientIp();
      $config =  \Drupal::configFactory()->get('syncloud.settings');
      if ($config->get('telegram-int')) {
        $uuid = \Drupal::state()->get('syncloud.uuid');
        $current_path = \Drupal::service('path.current')->getPath();
        $alias = \Drupal::service('path_alias.manager')->getAliasByPath($current_path);
        $msg = [
          'ip' => $ip,
          'type' => $form_id,
          'host' => \Drupal::request()->getHost(),
          'page' => \Drupal::request()->getSchemeAndHttpHost() . $alias,
        ];
        foreach ($entity->getFields() as $name => $field) {
          $msg['message--' . $name] = $field->getString();
        }
        \Drupal::service('syncloud.mqtt')->run()->publish("\$telega/syncloud/$uuid/event/contact-message", json_encode($msg));
      }

      $syn_array = [
        'name' => $ip . '--' . $form_id,
        'ip' => $ip,
        'host' => \Drupal::request()->getHost(),
        'page' => \Drupal::request()->getSchemeAndHttpHost(),
        'type' => $form_id,
        'message' => $entity->id(),
        'city' => [],
        'url' => \Drupal::service('path.current')->getPath(),
      ];
      $syn = $this->syn_storage->create($syn_array);
      $this->syn_storage->save($syn);
      $queue->deleteItem($item);
    }
  }
}
